@@ -1,5 +1,7 @@
 import json
 import threading
+import traceback
+
 import zmq
 
 
@@ -38,9 +40,13 @@ class ZMQSubscriber:
 
     def fetch_updates(self):
         while self.is_running:
-            message_data = self.socket.recv().decode()
-            _, _, message = message_data.partition(":")
-            self.callback(json.loads(message))
+            try:
+                message_data = self.socket.recv().decode()
+                _, _, message = message_data.partition(":")
+                self.callback(json.loads(message))
+            except:
+                print("Error: the received data contains problems.")
+                traceback.print_exc()
 
     def close_socket(self):
         self.is_running = False
